"""All plugging called to check norm for a C file."""
__all__ = [
    "columns",
    "comma",
    "function_line",
    "indent",
    "libc_func",
    "nested_branches",
    "number_function",
    "parenthesis",
    "preprocessor",
    "snake_case",
    "solo_space",
    "statements",
    "trailing_newline",
    "two_space",
    "operators"
]
